@@ -18,7 +18,11 @@ if [[ $CONDA_BUILD_CROSS_COMPILATION == 1 ]]; then
     export r_cv_have_curl_https=yes
     export r_cv_size_max=yes
     export r_cv_prog_fc_char_len_t=size_t
-    export r_cv_kern_usrstack=yes
+    if [[ "${target_platform}" == linux* ]]; then
+      export r_cv_kern_usrstack=no
+    else
+      export r_cv_kern_usrstack=yes
+    fi
     export ac_cv_lib_icucore_ucol_open=yes
     export ac_cv_func_mmap_fixed_mapped=yes
     export r_cv_working_mktime=yes
@@ -87,7 +91,7 @@ Linux() {
     unset JAVA_HOME
 
     export CPPFLAGS="${CPPFLAGS} -Wl,-rpath-link,${PREFIX}/lib"
-    
+
     # Make sure curl is found from PREFIX instead of BUILD_PREFIX
     rm "${BUILD_PREFIX}/bin/curl-config"
 
@@ -449,7 +453,7 @@ Darwin() {
     # http://openradar.appspot.com/radar?id=6069753579831296
     # .. anyway, uuid is part of libc on Darwin, so let's just try to use that.
     rm -f "${PREFIX}"/include/uuid/uuid.h
-    
+
     # Make sure curl is found from PREFIX instead of BUILD_PREFIX
     rm "${BUILD_PREFIX}/bin/curl-config"
 
@@ -482,6 +486,8 @@ Darwin() {
 
     pushd ${PREFIX}/lib/R/etc
       sed -i -r "s|-isysroot ${CONDA_BUILD_SYSROOT}||g" Makeconf
+      sed -i -r "s|$BUILD_PREFIX/lib/gcc|$PREFIX/lib/gcc|g" Makeconf
+      sed -i -r "s|$BUILD_PREFIX/lib/gcc|$PREFIX/lib/gcc|g" Makeconf-r
       # See: https://github.com/conda/conda/issues/6701
       chmod g+w Makeconf ldpaths
     popd
@@ -506,7 +512,7 @@ fi
 
 if [[ "$CONDA_BUILD_CROSS_COMPILATION" == "1" ]]; then
   pushd $BUILD_R_PREFIX/lib/R
-  rm etc/Makeconf-r
+  rm -f etc/Makeconf-r
   for f in $(find . -type f); do
     if [[ ! -f $PREFIX/lib/R/$f ]]; then
       mkdir -p $PREFIX/lib/R/$(dirname $f)
